summaryrefslogtreecommitdiffstats
path: root/src/core/hle/kernel/hle_ipc.h
diff options
context:
space:
mode:
authorZach Hilman <zachhilman@gmail.com>2018-11-27 00:32:52 +0100
committerZach Hilman <zachhilman@gmail.com>2018-11-29 14:42:26 +0100
commita56fc84e7a116681373ab9157193d2b8ae0f29af (patch)
tree15b327f2ed4c0e4a9a3ddd6a21e462fcfd83ec8a /src/core/hle/kernel/hle_ipc.h
parentkernel: Add named event table (diff)
downloadyuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar.gz
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar.bz2
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar.lz
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar.xz
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.tar.zst
yuzu-a56fc84e7a116681373ab9157193d2b8ae0f29af.zip
Diffstat (limited to '')
-rw-r--r--src/core/hle/kernel/hle_ipc.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/core/hle/kernel/hle_ipc.h b/src/core/hle/kernel/hle_ipc.h
index a38e34b74..557940f11 100644
--- a/src/core/hle/kernel/hle_ipc.h
+++ b/src/core/hle/kernel/hle_ipc.h
@@ -24,10 +24,11 @@ class ServiceFrameworkBase;
namespace Kernel {
class Domain;
-class Event;
class HandleTable;
class HLERequestContext;
class Process;
+class ReadableEvent;
+class WritableEvent;
/**
* Interface implemented by HLE Session handlers.
@@ -119,12 +120,15 @@ public:
* @param callback Callback to be invoked when the thread is resumed. This callback must write
* the entire command response once again, regardless of the state of it before this function
* was called.
* @param event Event to use to wake up the thread. If unspecified, an event will be created.
* @returns Event that when signaled will resume the thread and call the callback function.
*/
- SharedPtr<Event> SleepClientThread(SharedPtr<Thread> thread, const std::string& reason,
- u64 timeout, WakeupCallback&& callback,
- Kernel::SharedPtr<Kernel::Event> event = nullptr);
+ SharedPtr<WritableEvent> SleepClientThread(SharedPtr<Thread> thread, const std::string& reason,
+ u64 timeout, WakeupCallback&& callback,
+ SharedPtr<WritableEvent> writable_event = nullptr,
+ SharedPtr<ReadableEvent> readable_event = nullptr);
/// Populates this context with data from the requesting process/thread.
ResultCode PopulateFromIncomingCommandBuffer(const HandleTable& handle_table,
@@ -119,12 +120,15 @@ public:
* the entire command response once again, regardless of the state of it before this function
* was called.
- * @param event Event to use to wake up the thread. If unspecified, an event will be created.
+ * @param writable_event Event to use to wake up the thread. If unspecified, an event will be
+ * created.
+ * @param readable_event Event to be bound to the thread to wake up upon.
* @returns Event that when signaled will resume the thread and call the callback function.
*/